# cpalgo

cpalgo is a Python Library that contains over 100 standard competitive programming algorithms for faster access.
## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install cpalgo
```

## Usage

```python
import cpalgo

string1 = 'algorithms'
string2 = 'rhythms'

#To find the longest common subsequence between two strings
cpalgo.longest_common_subsequence(string1, string2) 

#To count the number of prime numbers in [1,N]
cpalgo.count_primes(234)

```

## Developers
[Narayanaa S R](https://srnarayanaa.me)

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[BSD](https://opensource.org/licenses/BSD-3-Clause)

## Project Status
This project is expected to be completed by June 2021.
